==> okta-sdk-api-19.0.1-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/WellKnownAppAuthenticatorConfigurationSettings.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.CustomAppUserVerificationEnum;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * WellKnownAppAuthenticatorConfigurationSettings
 */
@JsonPropertyOrder({ WellKnownAppAuthenticatorConfigurationSettings.JSON_PROPERTY_USER_VERIFICATION })
@JsonTypeName("WellKnownAppAuthenticatorConfiguration_settings")
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class WellKnownAppAuthenticatorConfigurationSettings implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_USER_VERIFICATION = "userVerification";
    private CustomAppUserVerificationEnum userVerification;

    public WellKnownAppAuthenticatorConfigurationSettings() {
    }

    public WellKnownAppAuthenticatorConfigurationSettings userVerification(
            CustomAppUserVerificationEnum userVerification) {

        this.userVerification = userVerification;
        return this;
    }

    /**
     * Get userVerification
     *
     * @return userVerification
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_USER_VERIFICATION)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public CustomAppUserVerificationEnum getUserVerification() {
        return userVerification;
    }

    @JsonProperty(JSON_PROPERTY_USER_VERIFICATION)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setUserVerification(CustomAppUserVerificationEnum userVerification) {
        this.userVerification = userVerification;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        WellKnownAppAuthenticatorConfigurationSettings wellKnownAppAuthenticatorConfigurationSettings = (WellKnownAppAuthenticatorConfigurationSettings) o;
        return Objects.equals(this.userVerification, wellKnownAppAuthenticatorConfigurationSettings.userVerification);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(userVerification);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class WellKnownAppAuthenticatorConfigurationSettings {\n");
        sb.append("    userVerification: ").append(toIndentedString(userVerification)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-20.0.1-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/WellKnownAppAuthenticatorConfigurationSettings.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.CustomAppUserVerificationEnum;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * WellKnownAppAuthenticatorConfigurationSettings
 */
@JsonPropertyOrder({ WellKnownAppAuthenticatorConfigurationSettings.JSON_PROPERTY_USER_VERIFICATION })
@JsonTypeName("WellKnownAppAuthenticatorConfiguration_settings")
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-01-23T09:50:29.349096-06:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class WellKnownAppAuthenticatorConfigurationSettings implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_USER_VERIFICATION = "userVerification";
    private CustomAppUserVerificationEnum userVerification;

    public WellKnownAppAuthenticatorConfigurationSettings() {
    }

    public WellKnownAppAuthenticatorConfigurationSettings userVerification(
            CustomAppUserVerificationEnum userVerification) {

        this.userVerification = userVerification;
        return this;
    }

    /**
     * Get userVerification
     *
     * @return userVerification
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_USER_VERIFICATION)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public CustomAppUserVerificationEnum getUserVerification() {
        return userVerification;
    }

    @JsonProperty(JSON_PROPERTY_USER_VERIFICATION)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setUserVerification(CustomAppUserVerificationEnum userVerification) {
        this.userVerification = userVerification;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        WellKnownAppAuthenticatorConfigurationSettings wellKnownAppAuthenticatorConfigurationSettings = (WellKnownAppAuthenticatorConfigurationSettings) o;
        return Objects.equals(this.userVerification, wellKnownAppAuthenticatorConfigurationSettings.userVerification);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(userVerification);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class WellKnownAppAuthenticatorConfigurationSettings {\n");
        sb.append("    userVerification: ").append(toIndentedString(userVerification)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
